from h5schemas.scan_schema import GroupDefinition
import h5py
import numpy as np


class BaseDataset:
    dataset: h5py.Dataset
    minimum: int | float | None = None
    maximum: int | float | None = None
    dtype: str | np.float64 | np.float32 | np.uint16 | None = None

    def __init__(self, definition: GroupDefinition):
        self.path = definition.path
        self.dataset_name = definition.path.rsplit("/")[-1]
        self.group = definition.path[: -len(self.dataset_name)]
        self.description = definition.description

    @classmethod
    def with_file(cls, definition: GroupDefinition, h5_file: h5py.File):
        instance = cls(definition)
        instance.add_to_file(h5_file)
        instance.add_description()
        return instance

    def add_to_file(self, h5_file: h5py.File):
        raise NotImplementedError("--- Add file needed ---")

    def add_description(self):
        self.dataset.attrs["description"] = self.description
