from h5py import File, Group
from thd_json import image
from h5schemas.scan_schema import open_schema
from h5schemas.initialize_dataset import initialize_dataset

from h5schemas.header.add_header import add_header_sample

import numpy as np
from pathlib import Path


def init_image_dataset(h5_file: File | Group, image_as_path: bool):
    schema_groups = open_schema(image, "image.json", image_as_path=image_as_path)
    initialize_dataset(h5_file, schema_groups)


def add_image_sample(
    h5_file: File | Group,
    image: Path | np.ndarray,
    uuid: str | None = None,
    timestamp: int | None = None,
):
    if isinstance(image, Path):
        dst = h5_file["image_path"]
        dst.resize((dst.shape[0] + 1,))
        dst[-1,] = str(image)
    else:
        dst = h5_file["image_array"]
        dst.resize((dst.shape[0] + 1, image.shape[0], image.shape[1]))
        dst[-1] = image

    add_header_sample(h5_file["header"], uuid, timestamp)


if __name__ == "__main__":
    test_file = File("./examples/image.h5", "w")
    init_image_dataset(test_file, False)

    add_image_sample(test_file, 1e5 * np.random.random((128, 128)))
    add_image_sample(test_file, 1e5 * np.random.random((128, 128)))
    print(test_file["/image_array"][...])
